@@ -1,7 +1,29 @@
 using System;
 using SemWeb;
+using System.IO;
+
+using Mono.Unix;
 
 namespace FSpot {
+	public class InfoDialog : Gtk.Dialog {
+		InfoDisplay info_display;
+		public InfoDisplay InfoDisplay {
+			get { return info_display; }
+		}
+
+		public InfoDialog (Gtk.Window parent) : base (Catalog.GetString ("Metadata Browser"),
+											    parent,
+											    Gtk.DialogFlags.NoSeparator | Gtk.DialogFlags.DestroyWithParent)
+		{
+			info_display = new InfoDisplay ();
+			SetDefaultSize (400, 400);
+			Gtk.ScrolledWindow scrolled = new Gtk.ScrolledWindow ();
+			VBox.PackStart (scrolled);
+			scrolled.Add (info_display);
+		}
+	}
+
+
 	public class InfoDisplay : Gtk.HTML {
 		public InfoDisplay () 
 		{
@@ -22,13 +44,24 @@ namespace FSpot {
 					exif_info.Dispose ();
 
 				if (photo != null) {
-					exif_info = new Exif.ExifData (photo.DefaultVersionUri.LocalPath);
+					if (File.Exists (photo.DefaultVersionUri.LocalPath))
+						exif_info = new Exif.ExifData (photo.DefaultVersionUri.LocalPath);
 				} else {
 					exif_info = null;
 				}
 				this.Update ();
 			}
 		}
+
+		protected override void OnLinkClicked (string url)
+		{
+                        if (url.StartsWith ("/")) {
+                                // do a lame job of creating a URI out of local paths
+                                url = "file://" + url;
+                        }
+                        
+                        GnomeUtil.UrlShow (null, url);
+		}
 		
 		protected override void OnStyleSet (Gtk.Style previous)
 		{
@@ -69,6 +102,49 @@ namespace FSpot {
 			return value;
 		}
 
+		private static string GetExportUrl (ExportItem export)
+		{
+			switch (export.ExportType) {
+			case ExportStore.FlickrExportType:
+				string[] split_token = export.ExportToken.Split (':');
+				return String.Format ("http://www.{0}/photos/{1}/{2}/", split_token[2],
+                                                      split_token[0], split_token[3]);
+			case ExportStore.FolderExportType:
+				Gnome.Vfs.Uri uri = new Gnome.Vfs.Uri (export.ExportToken);
+				return (uri.HasParent) ? uri.Parent.ToString () : export.ExportToken;
+			case ExportStore.Gallery2ExportType:
+				string[] split_item = export.ExportToken.Split (':');
+				return String.Format ("{0}:{1}?g2_itemId={2}",split_item[0], split_item[1], split_item[2]);
+			case ExportStore.OldFolderExportType:	//This is obsolete and meant to be removed once db reach rev4
+			case ExportStore.PicasaExportType:
+			case ExportStore.SmugMugExportType:
+				return export.ExportToken;
+			default:
+				return null;
+			}
+		}
+
+		private static string GetExportLabel (ExportItem export)
+		{
+			switch (export.ExportType) {
+			case ExportStore.FlickrExportType:
+				string[] split_token = export.ExportToken.Split (':');
+				return String.Format ("Flickr ({0})", split_token[1]);
+			case ExportStore.OldFolderExportType:	//Obsolete, remove after db rev4
+				return Catalog.GetString ("Folder");
+			case ExportStore.FolderExportType:
+				return Catalog.GetString ("Folder");
+			case ExportStore.PicasaExportType:
+				return Catalog.GetString ("Picasaweb");
+			case ExportStore.SmugMugExportType:
+				return Catalog.GetString ("SmugMug");
+			case ExportStore.Gallery2ExportType:
+				return Catalog.GetString ("Gallery2");
+			default:
+				return null;
+			}
+		}
+
 		private void Update ()
 		{
 			Gtk.HTMLStream stream = this.Begin (null, "text/html; charset=utf-8", Gtk.HTMLBeginFlags.Scroll);
@@ -80,6 +156,7 @@ namespace FSpot {
 			stream.Write ("<table width=100% cellpadding=5 cellspacing=0>");
 			bool empty = true;
 			bool missing = false;
+			System.Exception error = null;
 
 			if (exif_info != null) {
 				foreach (Exif.ExifContent content in exif_info.GetContents ()) {
@@ -106,12 +183,12 @@ namespace FSpot {
 						      + Exif.ExifUtil.GetIfdNameExtended ((Exif.Ifd)i - 1) + "</th><tr>");
 					
 					foreach (Exif.ExifEntry entry in entries) {
-						stream.Write ("<tr><td valign=top align=right bgcolor=\""+ bg + "\"><font color=\"" + fg + "\">");
+						stream.Write ("<tr><td valign=top align=right bgcolor=\""+ bg + "\"><small><font color=\"" + fg + "\">");
 						if (entry.Title != null)
 							stream.Write (entry.Title);
 						else
 							stream.Write ("&lt;Unknown Tag ID=" + entry.Tag.ToString () + "&gt;");
-						stream.Write ("</font></td><td>");
+						stream.Write ("</font></small></td><td>");
 						string s = entry.Value;
 						if (s != null && s != "")
 							stream.Write (s);
@@ -123,14 +200,22 @@ namespace FSpot {
 			if (photo != null) {
 				MetadataStore store = new MetadataStore ();
 				try {
-					ImageFile img = ImageFile.Create (photo.DefaultVersionUri.LocalPath);
+					ImageFile img = ImageFile.Create (photo.DefaultVersionUri);
 					if (img is SemWeb.StatementSource) {
 						StatementSource source = (StatementSource)img;
 						source.Select (store);
 					}
-				} catch (System.IO.FileNotFoundException nf) {
+				} catch (System.IO.FileNotFoundException) {
 					missing = true;
-				} 
+				} catch (System.Exception e){
+					// Sometimes we don't get the right exception, check for the file
+					if (!System.IO.File.Exists (photo.DefaultVersionUri.LocalPath)) {
+						missing = true;
+					} else {
+						// if the file is there but we still got an exception display it.
+						error = e;
+					}
+				}
 				
 				if (store.StatementCount > 0) {
 #if false
@@ -145,12 +230,12 @@ namespace FSpot {
 #endif
 					empty = false;
 					stream.Write ("<tr><th align=left bgcolor=\"" + ig + "\" colspan=2>" 
-						      + Mono.Posix.Catalog.GetString ("Extended Metadata") + "</th><tr>");
+						      + Catalog.GetString ("Extended Metadata") + "</th></tr>");
 					
 					foreach (Statement stmt in store) {
 						// Skip anonymous subjects because they are
 						// probably part of a collection
-						if (stmt.Subject.Uri == null) 
+						if (stmt.Subject.Uri == null && store.SelectSubjects (null, stmt.Subject).Length > 0)
 							continue;
 						
 						string title;
@@ -158,21 +243,37 @@ namespace FSpot {
 
 						Description.GetDescription (store, stmt, out title, out value);
 
-						stream.Write ("<tr><td valign=top align=right bgcolor=\""+ bg + "\"><font color=\"" + fg + "\">");
+						stream.Write ("<tr><td valign=top align=right bgcolor=\""+ bg + "\"><small><font color=\"" + fg + "\">");
 						stream.Write (title);
-						stream.Write ("</font></td><td width=100%>");
+						stream.Write ("</font></small></td><td width=100%>");
 						
 					        if (value != null)
 							value = Escape (value);
 						else {
-							MemoryStore substore = store.Select (new Statement ((Entity)stmt.Object, null, null, null));
+							MemoryStore substore = store.Select (new Statement ((Entity)stmt.Object, null, null, null)).Load();
 							WriteCollection (substore, stream);
 						}
 						
 						if (value != null && value != "")
 							stream.Write (value);
 						
-						stream.Write ("</td><tr>");
+						stream.Write ("</td></tr>");
+					}
+				}
+				
+				if (Core.Database != null) {
+					stream.Write ("<tr><th align=left bgcolor=\"" + ig + "\" colspan=2>" + Catalog.GetString ("Exported Locations") + "</th></tr>");
+	
+					Photo p = photo as Photo;
+					foreach (ExportItem export in Core.Database.Exports.GetByImageId (p.Id, p.DefaultVersionId)) {
+						string url = GetExportUrl (export);
+						string label = GetExportLabel (export);
+						if (url == null || label == null)
+							continue;
+	                                        
+						stream.Write ("<tr colspan=2><td width=100%>");
+						stream.Write (String.Format ("<a href=\"{0}\">{1}</a>", url, label));
+						stream.Write ("</font></small></td></tr>");
 					}
 				}
 			}
@@ -184,15 +285,19 @@ namespace FSpot {
 					// handle multiple items however it wants.
 					msg = String.Format ("<tr><td valign=top align=center bgcolor=\"{0}\">" 
 							     + "<b>{1}</b></td></tr>", ig,
-							     Mono.Posix.Catalog.GetString ("No active photo"));
+							     Catalog.GetString ("No active photo"));
 				} else if (missing) {
-					string text = String.Format (Mono.Posix.Catalog.GetString ("The photo \"{0}\" does not exist"), photo.DefaultVersionUri);
+					string text = String.Format (Catalog.GetString ("The photo \"{0}\" does not exist"), photo.DefaultVersionUri);
 					msg = String.Format ("<tr><td valign=top align=center bgcolor=\"{0}\">" 
 							     + "<b>{1}</b></td></tr>", ig, text);
 				} else {
 					msg = String.Format ("<tr><td valign=top align=center bgcolor=\"{0}\">" 
 							     + "<b>{1}</b></td></tr>", ig,
-							     Mono.Posix.Catalog.GetString ("No metadata available"));
+							     Catalog.GetString ("No metadata available"));
+
+					if (error != null) {
+						String.Format ("<pre>{0}</pre>", error);
+					}
 				}
 				stream.Write (msg);
 			}
@@ -206,17 +311,16 @@ namespace FSpot {
 			string type = null;
 
 			foreach (Statement stmt in substore) {
-				if (stmt.Predicate == MetadataStore.Namespaces.Resolve ("rdf:type")) {
+				if (stmt.Predicate.Uri == MetadataStore.Namespaces.Resolve ("rdf:type")) {
 					string prefix;
-					MetadataStore.Namespaces.Normalize (stmt.Object.ToString (), out prefix, out type);
+					MetadataStore.Namespaces.Normalize (stmt.Object.Uri, out prefix, out type);
 				}
 			}
 			
 			stream.Write ("<table cellpadding=5 cellspacing=0 width=100%>");
 			foreach (Statement sub in substore) {
 				if (sub.Object is Literal) {
-					string predicate = sub.Predicate.ToString ();
-					string title = System.IO.Path.GetFileName (predicate);
+					string title;
 					string value = ((Literal)(sub.Object)).Value;
 					string vc = "";
 					
@@ -238,7 +342,7 @@ namespace FSpot {
 				} else {
 					if (type == null) {
 						stream.Write ("<tr><td>");
-						MemoryStore substore2 = substore.Select (new Statement ((Entity)sub.Object, null, null, null));
+						MemoryStore substore2 = substore.Select (new Statement ((Entity)sub.Object, null, null, null)).Load();
 						if (substore.StatementCount > 0)
 							WriteCollection (substore2, stream);
 						stream.Write ("</tr><td>");
@@ -263,7 +367,7 @@ namespace FSpot {
 
 			public bool Add (SemWeb.Statement stmt)
 			{
-				string predicate = stmt.Predicate.ToString ();
+				string predicate = stmt.Predicate.Uri;
 				string title = System.IO.Path.GetFileName (predicate);
 				string bg = InfoDisplay.Color (info.Style.Background (Gtk.StateType.Active));
 				string fg = InfoDisplay.Color (info.Style.Foreground (Gtk.StateType.Active));
