@@ -94,6 +94,7 @@ namespace FSpot
 		public const string EXPORT_FOLDER_OPEN = "/apps/f-spot/export/folder/browser";
 		public const string EXPORT_FOLDER_ROTATE = "/apps/f-spot/export/folder/rotate";
 		public const string EXPORT_FOLDER_METHOD = "/apps/f-spot/export/folder/method";
+		public const string EXPORT_FOLDER_URI = "/apps/f-spot/export/folder/uri";
 		
  		public const string EXPORT_EMAIL_SIZE = "/apps/f-spot/export/email/size";
  		public const string EXPORT_EMAIL_ROTATE = "/apps/f-spot/export/email/auto_rotate";
@@ -110,6 +111,8 @@ namespace FSpot
 		public const string GNOME_SCREENSAVER_THEME = "/apps/gnome-screensaver/themes";
 		public const string GNOME_SCREENSAVER_MODE = "/apps/gnome-screensaver/mode";
 
+		public const string GNOME_MAILTO_COMMAND = "/desktop/gnome/url-handlers/mailto/command";
+
 
 		static GConf.Client client;
 		static GConf.NotifyEventHandler changed_handler;
