@@ -65,7 +65,7 @@ namespace FSpot
 			}
 
 			foreach (string s in RemainingArguments)
-				if (s.StartsWith("-") && s != "--uninstalled" && s != "--debug" && s != "--trace" && s != "--profile") {
+				if (s.StartsWith("-") && s != "--uninstalled" && s != "--debug" && s != "--trace" && s != "--profile" && s != "--sync") {
 					Console.WriteLine ("Unknown option {0}", s);
 					return false;
 				}
@@ -82,7 +82,6 @@ public class Driver {
 
 		SetProcessName (Defines.PACKAGE);
 		
-		NDesk.DBus.BusG.Init();
 		try {
 			FSpotOptions options = new FSpotOptions ();
 			options.ProcessArgs (args);
@@ -107,7 +106,7 @@ public class Driver {
 					
 				program = new Program (Defines.PACKAGE, 
 						       Defines.VERSION, 
-					       Modules.UI, args);
+						       Modules.UI, args);
 				Core core = new Core ();
 				core.ShowSlides (null);
 				program.Run ();
@@ -115,6 +114,7 @@ public class Driver {
 				return;
 			}
 
+			NDesk.DBus.BusG.Init();
 			/* 
 			 * FIXME we need to inialize gobject before making the dbus calls, we'll go 
 			 * ahead and do it like this for now.
@@ -146,12 +146,12 @@ public class Driver {
 												PixbufUtils.LoadFromAssembly ("f-spot-22.png"),
 												PixbufUtils.LoadFromAssembly ("f-spot-32.png"),
 												PixbufUtils.LoadFromAssembly ("f-spot-48.png")};
-						core = new Core ();
+						core = new Core (options.view);
 						core.RegisterServer ();
 						
 						// FIXME: Error checking is non-existant here...
 						
-						empty = Core.Database.Empty;
+						empty = options.view || Core.Database.Empty;
 						control = core;
 					}
 				} catch (System.Exception e) {
@@ -161,6 +161,8 @@ public class Driver {
 					if (core != null)
 						core.UnregisterServer ();
 				}
+				if (control == null)
+					System.Console.WriteLine ("Cant' get a connection to the dbus. Trying again...");
 			}
 			
 			
@@ -186,7 +188,7 @@ public class Driver {
 					control.View (list.ToString ());
 			}
 			
-			if (empty && options.import == null)
+			if (empty && options.import == null && !options.view)
 				control.Import (null);
 			
 			if (options.import != null || !options.view) {
